@@ -1,8 +1,5 @@
 var classb2_broad_phase =
 [
-    [ "e_nullProxy", "classb2_broad_phase.html#ad14dca932793724b27024e60a6ade466a8a4f9965a5b0bbb13a35c20a37fef0ad", null ],
-    [ "b2BroadPhase", "classb2_broad_phase.html#ac58820d4cb10df81a33923c7c75d8f85", null ],
-    [ "~b2BroadPhase", "classb2_broad_phase.html#a40cebf62f00ebfa7ca373ad96f76661f", null ],
     [ "CreateProxy", "classb2_broad_phase.html#ae2f7af756bc55ece45221466c5af449c", null ],
     [ "DestroyProxy", "classb2_broad_phase.html#a84f0fb227dc01a9b9baa55c7b8c68984", null ],
     [ "GetFatAABB", "classb2_broad_phase.html#af5c47c036ca67d44676ea3cec73ae3d8", null ],
@@ -17,6 +14,5 @@ var classb2_broad_phase =
     [ "ShiftOrigin", "classb2_broad_phase.html#a410e6115e3d1b4fca61cfbf397767772", null ],
     [ "TestOverlap", "classb2_broad_phase.html#a263cc21e2a3f1f892c20b048eca3cad6", null ],
     [ "TouchProxy", "classb2_broad_phase.html#a67b296431ebbc7b44037f21d645d9166", null ],
-    [ "UpdatePairs", "classb2_broad_phase.html#a0a1acd693466b997700242ae00784c20", null ],
-    [ "b2DynamicTree", "classb2_broad_phase.html#afc450dc71ee33ab0c9e7f1c31d6f7f60", null ]
+    [ "UpdatePairs", "classb2_broad_phase.html#a0a1acd693466b997700242ae00784c20", null ]
 ];
\ No newline at end of file
