@@ -6,8 +6,5 @@ var structb2_mat33 =
     [ "GetSymInverse33", "structb2_mat33.html#a2620944663233096d3b82bc4b1a991e9", null ],
     [ "SetZero", "structb2_mat33.html#a42fc6953b025e1c8b59717d0ee7accde", null ],
     [ "Solve22", "structb2_mat33.html#acdf892aab7e26283f8aa600ade91dcef", null ],
-    [ "Solve33", "structb2_mat33.html#a2ce48f409ba5951a04da821dada9e285", null ],
-    [ "ex", "structb2_mat33.html#a132f00e6550d1e19c75fb60ce1229638", null ],
-    [ "ey", "structb2_mat33.html#ababc69c718c73a04a651f7a6a981ecf4", null ],
-    [ "ez", "structb2_mat33.html#ae700fc46f679b4ef211a2517005b0557", null ]
+    [ "Solve33", "structb2_mat33.html#a2ce48f409ba5951a04da821dada9e285", null ]
 ];
\ No newline at end of file
